@@ -32,7 +32,7 @@ logger = logging.getLogger(__name__)
 def _cache(cache_size=None, cache_ttl=None, **kwargs):
     """Cache factory"""
     if cache_size is None:
-        return dict()  # for testing/debugging
+        return None  # mainly for testing/debugging
     elif cache_ttl is None:
         return cachetools.LRUCache(cache_size)
     else:
@@ -43,7 +43,10 @@ def _ref(metadata):
     identifier = metadata['identifier']
     uri = _URI_PREFIX + identifier
     name = metadata.get('title', identifier)
-    return Ref.directory(uri=uri, name=name)
+    if metadata.get('mediatype', 'collection') == 'collection':
+        return Ref.directory(uri=uri, name=name)
+    else:
+        return Ref.album(uri=uri, name=name)
 
 
 def _artists(metadata, default=[]):
@@ -79,7 +82,7 @@ def _track(metadata, file, album):
         date=parse_date(file.get('date'), album.date),
         length=parse_length(file.get('length')),
         bitrate=parse_bitrate(file.get('bitrate')),
-        comment=metadata.get('description'),
+        # FIXME: comment=metadata.get('description'),
         last_modified=parse_mtime(file.get('mtime'))
     )
 
@@ -214,7 +217,7 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
         collections = self._config['collections']
         result = self.backend.client.search(
             _query(identifier=collections, mediatype='collection'),
-            fields=['identifier', 'title'],
+            fields=['identifier', 'title', 'mediatype'],
             rows=len(collections)
         )
         # return in same order as listed in config
@@ -231,11 +234,11 @@ class InternetArchiveLibraryProvider(backend.LibraryProvider):
     def _browse_collection(self, identifier):
         result = self.backend.client.search(
             _query(collection=identifier, **self._search_filter),
-            fields=['identifier', 'title'],
+            fields=['identifier', 'title', 'mediatype'],
             sort=self._config['browse_order'],
             rows=self._config['browse_limit']
         )
-        return [_ref(doc) for doc in result]
+        return map(_ref, result)
 
     @cachetools.cachedmethod(operator.attrgetter('_cache'))
     def _browse_item(self, identifier):
